clear all
set mem 500m
set matsize 800
set more 1

use "POQ_PublicReplicationDatafile.dta", clear

****************************
*
* ANALYSIS
*
****************************
* SET DEMOGRAPHIC CONTROL VARIABLES / SET BLOCK OF SOCIAL PREDICTORS 
****************************
local controls="r_black r_hispanic r_otherrace educ income incomemis gender age age2"
local social="agree_family agree_friends agree_family_dk agree_friends_dk"

* CROSSTABS
** FIGURE 1: 3 ITEMS
tab treat_ch_private [aw=weight]
tab discuss_for_info [aw=weight] 
tab discuss_bad_press [aw=weight]

** IN TEXT INFO
tab treat_ch_private [aw=weight] if discuss_for_info<.5
tab treat_ch_private [aw=weight] if discuss_for_info>.5

tab treat_ch_private [aw=weight] if discuss_bad_press<.5
tab treat_ch_private [aw=weight] if discuss_bad_press>.5

** Secrecy Prefs and Friends/Family Know choices. These results are reported in the Supplemental Appendix Section 1.
forvalues i=160/163{
tab yal`i' treat_ch_private [aw=weight], col
}

** TABLE 1: PREFERENCES FOR DELIBERATION BY SELECTED INDIVIDUAL CHARACTERISTICS
*** LEFT SIDE: POLITICAL RESOURCES
*** RIGHT SIDE: STRENGTH OF POLITICAL PREFERENCES AND SOCIAL NETWORK AGREEMENT
*** APPENDIX TABLE A3: TRUST AND EXTERNAL EFFICACY (POTENTIAL CONFOUNDS)

* Generate High/Low Indicator Variables
foreach i in int_efficacy strpref agree_family agree_friends pers_trust gov_trust ext_efficacy {
gen high_`i' = 0
gen low_`i' = 0
replace high_`i' = 1 if `i'>1
replace low_`i' = 1 if `i'<-1
label var high_`i' "High `i' = 1"
label var low_`i' "Low `i' = 1"
}

foreach i in interest pknow {
gen high_`i' = 0
gen low_`i' = 0
replace high_`i' = 1 if `i'>.5
replace low_`i' = 1 if `i'<-1
label var high_`i' "High `i' = 1"
label var low_`i' "Low `i' = 1"
}

* And Middle Indicator
foreach i in int_efficacy strpref agree_family agree_friends pers_trust gov_trust ext_efficacy {
gen middle_`i' = 0
replace middle_`i' = 1 if `i'<=1 &`i'>=-1
label var middle_`i' "Middle `i' = 1"
}

foreach i in interest pknow {
gen middle_`i' = 0
replace middle_`i' = 1 if `i'<=.5 & `i'>=-1
label var middle_`i' "Middle `i' = 1"
}

file open myfile using "Table01.csv", write replace
file write myfile "Preference for Discussing Vote Choices with Others by Selected Individual Characteristics" _n
file write myfile _n
file write myfile "Low Middle High,Internal Efficacy,Political Knowledge,Political Interest,Strength of Preferences,Agreement with Family,Agreement with Friends" _n
file write myfile _n

foreach j in low middle high{
file write myfile "`j',"
foreach i in int_efficacy pknow interest strpref agree_family agree_friends {
sum treat_ch_private [aw=weight] if `j'_`i'==1
file write myfile "`r(mean)',"
}
file write myfile _n
}
file close myfile

*** AND P-VALUES FOR TEST OF DIFFERENCE OF PROPORTIONS (HIGH-LOW ON CHARACTERISTIC)
foreach i in int_efficacy strpref pknow interest agree_family agree_friends {
gen lh_`i' = 1 if high_`i'==1
replace lh_`i' = 0 if low_`i'==1
label var lh_`i' "`i', High=1, Low=0, Else=missing"
}

foreach i in int_efficacy pknow interest strpref agree_family agree_friends {
reg treat_ch_private lh_`i' [aw=weight] 
test lh_`i' 
if `i'==int_efficacy {
outreg using "Table01pvalues.out", se bracket rdec(3) replace 3aster addstat("Significance", r(p)) adec(3)
}
 else {
outreg using "Table01pvalues.out", se bracket rdec(3) append 3aster addstat("Significance", r(p)) adec(3)
}
}

** APPENDIX TABLE S1 (CORRELATIONS BETWEEN INDPENDENT VARIABLES)
corr r_black r_hispanic r_otherrace educ income incomemis gender age age2 int_efficacy pkno interest strprefs agree_family agree_friends agree_family_dk agree_friends_dk 

** TABLE 2 
foreach i in treat_ch_private discuss_for_info discuss_bad_pressure {
reg `i' `controls' capable strprefs `social' state* [aw=weight], r
test educ income incomemis
if "`i'"=="treat_ch_private"{
outreg `controls' capable strprefs `social' using "table02.out", se bracket rdec(3) replace adec(3) addstat("Joint significance of SES", r(p)) 3aster
}
else{
outreg `controls' capable strprefs `social' using "table02.out", se bracket rdec(3) append adec(3) addstat("Joint significance of SES", r(p)) 3aster
}

reg `i' `controls' capable strprefs `social' pers_trust gov_trust ext_efficacy state* [aw=weight], r
test educ income incomemis
outreg `controls' capable strprefs `social' pers_trust gov_trust ext_efficacy using "table02.out", se bracket rdec(3) append adec(3) addstat("Joint significance of SES", r(p)) 3aster
}

** APPENDIX TABLE S2, Logit/Ordered logit version of Table 2
foreach i in treat_ch_private discuss_for_info discuss_bad_pressure {
 if "`i'"=="treat_ch_private" {
  logit `i' `controls' capable strprefs `social' state* [pw=weight], r
  test educ income incomemis
  outreg `controls' capable strprefs `social' using "TableS02.out", se bracket rdec(3) replace adec(3) addstat("Joint significance of SES", r(p)) 3aster
  
  logit `i' `controls' capable strprefs `social' pers_trust gov_trust ext_efficacy state* [pw=weight], r
  test educ income incomemis
  outreg `controls' capable strprefs `social' pers_trust gov_trust ext_efficacy using "TableS02.out", se bracket rdec(3) append adec(3) addstat("Joint significance of SES", r(p)) 3aster 
 }
 else {
  ologit `i' `controls' capable strprefs `social' state* [pw=weight], r
  test educ income incomemis
  outreg `controls' capable strprefs `social' using "TableS02.out", se bracket rdec(3) append adec(3) addstat("Joint significance of SES", r(p)) 3aster

  ologit `i' `controls' capable strprefs `social' pers_trust gov_trust ext_efficacy state* [pw=weight], r
  test educ income incomemis
  outreg `controls' capable strprefs `social' pers_trust gov_trust ext_efficacy using "TableS02.out", se bracket rdec(3) append adec(3) addstat("Joint significance of SES", r(p)) 3aster 
 }
}

** APPENDIX TABLE S3, Testing for interactions
foreach i in treat_ch_private discuss_for_info discuss_bad_pressure {
 reg `i' `controls' capable strprefs `social' *Xcapable state* [aw=weight], r
 test familyXcapable familydkXcapable friendsXcapable friendsdkXcapable
 if "`i'"=="treat_ch_private"{
  outreg `controls' capable strprefs `social' *Xcapable using "TableS03.out", se bracket rdec(3) replace adec(3) addstat("Joint significance Resources Interactions", r(p)) 3aster
 }
 else {
  outreg `controls' capable strprefs `social' *Xcapable using "TableS03.out", se bracket rdec(3) append adec(3) addstat("Joint significance Resources Interactions", r(p)) 3aster
 }
 reg `i' `controls' capable strprefs `social' *Xstrpref state* [aw=weight], r
 test familyXstrpref familydkXstrpref friendsXstrpref friendsdkXstrpref
 local strpref=r(p)
 outreg `controls' capable strprefs `social' *Xstrpref using "TableS03.out", se bracket rdec(3) append adec(3) addstat("Joint significance Strength of Pref Interactions", r(p)) 3aster
}

** APPENDIX TABLE S4, Additional measures 
file open myfile using "TableS04.csv", write replace
file write myfile "Preference for Discussing Vote Choices with Others by Selected Individual Characteristics" _n
file write myfile _n
file write myfile "Low Middle High,Interpersonal Trust, Trust in Government, External Efficacy" _n
file write myfile _n

foreach j in low middle high{
file write myfile "`j',"
foreach i in pers_trust gov_trust ext_efficacy {
sum treat_ch_private [aw=weight] if `j'_`i'==1
file write myfile "`r(mean)',"
}
file write myfile _n
}
file close myfile

*** AND P-VALUES FOR TEST OF DIFFERENCE OF PROPORTIONS (HIGH-LOW ON CHARACTERISTIC)
foreach i in pers_trust gov_trust ext_efficacy {
gen lh_`i' = 1 if high_`i'==1
replace lh_`i' = 0 if low_`i'==1
label var lh_`i' "`i', High=1, Low=0, Else=missing"
}

foreach i in pers_trust gov_trust ext_efficacy {
reg treat_ch_private lh_`i' [aw=weight] 
test lh_`i' 
if `i'==pers_trust {
outreg using "TableS04pvalues.out", se bracket rdec(3) replace 3aster addstat("Significance", r(p)) adec(3)
}
 else {
outreg using "TableS04pvalues.out", se bracket rdec(3) append 3aster addstat("Significance", r(p)) adec(3)
}
}
